@@ -197,11 +197,12 @@ void tst_WebSocketFrame::tst_copyConstructorAndAssignment()
     QBuffer buffer(&payload);
     buffer.open(QIODevice::ReadOnly);
 
-    QWebSocketFrame frame = QWebSocketFrame::readFrame(&buffer);
+    QWebSocketFrame frame;
+    frame.readFrame(&buffer);
     buffer.close();
 
+    auto compareFrames = [](const QWebSocketFrame &other, const QWebSocketFrame &frame)
     {
-        QWebSocketFrame other(frame);
         QCOMPARE(other.closeCode(), frame.closeCode());
         QCOMPARE(other.closeReason(), frame.closeReason());
         QCOMPARE(other.hasMask(), frame.hasMask());
@@ -216,24 +217,20 @@ void tst_WebSocketFrame::tst_copyConstructorAndAssignment()
         QCOMPARE(other.rsv1(), frame.rsv1());
         QCOMPARE(other.rsv2(), frame.rsv2());
         QCOMPARE(other.rsv3(), frame.rsv3());
+    };
+
+    {
+        QWebSocketFrame other(frame);
+        compareFrames(other, frame);
     }
     {
         QWebSocketFrame other;
         other = frame;
-        QCOMPARE(other.closeCode(), frame.closeCode());
-        QCOMPARE(other.closeReason(), frame.closeReason());
-        QCOMPARE(other.hasMask(), frame.hasMask());
-        QCOMPARE(other.isContinuationFrame(), frame.isContinuationFrame());
-        QCOMPARE(other.isControlFrame(), frame.isControlFrame());
-        QCOMPARE(other.isDataFrame(), frame.isDataFrame());
-        QCOMPARE(other.isFinalFrame(), frame.isFinalFrame());
-        QCOMPARE(other.isValid(), frame.isValid());
-        QCOMPARE(other.mask(), frame.mask());
-        QCOMPARE(other.opCode(), frame.opCode());
-        QCOMPARE(other.payload(), frame.payload());
-        QCOMPARE(other.rsv1(), frame.rsv1());
-        QCOMPARE(other.rsv2(), frame.rsv2());
-        QCOMPARE(other.rsv3(), frame.rsv3());
+        compareFrames(other, frame);
+        QWebSocketFrame other2 = std::move(other);
+        compareFrames(other2, frame);
+        QWebSocketFrame other3(std::move(other2));
+        compareFrames(other3, frame);
     }
 }
 
@@ -330,7 +327,8 @@ void tst_WebSocketFrame::tst_goodFrames()
     QBuffer buffer;
     buffer.setData(wireRepresentation);
     buffer.open(QIODevice::ReadOnly);
-    QWebSocketFrame frame = QWebSocketFrame::readFrame(&buffer);
+    QWebSocketFrame frame;
+    frame.readFrame(&buffer);
     buffer.close();
     QVERIFY(frame.isValid());
     QCOMPARE(frame.rsv1(), rsv1);
@@ -495,7 +493,8 @@ void tst_WebSocketFrame::tst_invalidFrames()
     QBuffer buffer;
     buffer.setData(wireRepresentation);
     buffer.open(QIODevice::ReadOnly);
-    QWebSocketFrame frame = QWebSocketFrame::readFrame(&buffer);
+    QWebSocketFrame frame;
+    frame.readFrame(&buffer);
     buffer.close();
 
     QVERIFY(!frame.isValid());
@@ -542,7 +541,7 @@ void tst_WebSocketFrame::tst_malformedFrames_data()
     //too much data
     {
         const char bigpayloadIndicator = char(127);
-        const quint64 payloadSize = MAX_FRAME_SIZE_IN_BYTES + 1;
+        const quint64 payloadSize = QWebSocketFrame::maxFrameSize() + 1;
         uchar swapped[8] = {0};
         qToBigEndian<quint64>(payloadSize, swapped);
         QTest::newRow("Frame too big")
@@ -606,7 +605,8 @@ void tst_WebSocketFrame::tst_malformedFrames()
     QBuffer buffer;
     buffer.setData(payload);
     buffer.open(QIODevice::ReadOnly);
-    QWebSocketFrame frame = QWebSocketFrame::readFrame(&buffer);
+    QWebSocketFrame frame;
+    frame.readFrame(&buffer);
     buffer.close();
 
     QVERIFY(!frame.isValid());
